package com.bonus.material.purchase.service;

import java.util.List;

import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.material.purchase.domain.PurchaseCheckDetails;
import com.bonus.material.purchase.domain.dto.PurchaseCheckFileDto;
import org.apache.ibatis.annotations.Param;

/**
 * 新购验收任务详细Service接口
 * 
 * @author xsheng
 * @date 2024-10-16
 */
public interface IPurchaseCheckDetailsService {
    /**
     * 查询新购验收任务详细
     * 
     * @param id 新购验收任务详细主键
     * @return 新购验收任务详细
     */
    PurchaseCheckDetails selectPurchaseCheckDetailsById(Long id);

    /**
     * 查询新购验收任务详细列表
     * 
     * @param purchaseCheckDetails 新购验收任务详细
     * @return 新购验收任务详细集合
     */
    List<PurchaseCheckDetails> selectPurchaseCheckDetailsList(PurchaseCheckDetails purchaseCheckDetails);

    /**
     * 根据任务ID查询报告附件列表
     * @param taskId 任务id
     */
    List<PurchaseCheckFileDto> selectPurchaseCheckFileListByTaskType(Long taskId, Long typeId);

    /**
     * 新增报告附件
     * @param purchaseCheckFileDto 附件信息
     */
    AjaxResult insertPurchaseCheckFile(PurchaseCheckFileDto purchaseCheckFileDto);

    /**
     * 新增新购验收任务详细
     * 
     * @param purchaseCheckDetails 新购验收任务详细
     * @return 结果
     */
    int insertPurchaseCheckDetails(PurchaseCheckDetails purchaseCheckDetails);

    /**
     * 修改新购验收任务详细
     * 
     * @param purchaseCheckDetails 新购验收任务详细
     * @return 结果
     */
    int updatePurchaseCheckDetails(PurchaseCheckDetails purchaseCheckDetails);

    /**
     * 批量修改新购验收任务详细状态 -- 批量、限制状态
     * @param taskId 任务id
     * @param newTaskStatus 新状态
     */
    int batchUpdateDetailsTaskStatus(@Param("taskId") Long taskId, @Param("newTaskStatus") Integer newTaskStatus, String checkResult);

    /**
     * 批量删除新购验收任务详细
     * 
     * @param ids 需要删除的新购验收任务详细主键集合
     * @return 结果
     */
    int deletePurchaseCheckDetailsByIds(Long[] ids);

    /**
     * 删除新购验收任务详细信息
     * 
     * @param id 新购验收任务详细主键
     * @return 结果
     */
    int deletePurchaseCheckDetailsById(Long id);
}
